@@ -1,22 +1,19 @@
 package Net::APNS;
 
-use Moose;
+use Any::Moose;
 use Net::APNS::Notification;
-our $VERSION = '0.0101';
+our $VERSION = '0.02';
 
 sub notify {
-    my ($self, $args) = @_;
+    my ( $self, $args ) = @_;
     return Net::APNS::Notification->new(
-        cert        => $args->{cert},
-        key         => $args->{key},
-        passwd      => $args->{passwd},
+        cert   => $args->{cert},
+        key    => $args->{key},
+        passwd => $args->{passwd},
     );
 }
 
 __PACKAGE__->meta->make_immutable;
-no Moose;
-
-1;
 __END__
 
 =head1 NAME
@@ -36,17 +33,67 @@ Net::APNS - Apple Push Notification Service for perl.
   $Notifier->message("message");
   $Notifier->badge(4);
   $Notifier->write;
+
 =head1 DESCRIPTION
 
 Net::APNS is Apple Push Notification Service.
 Push message to iPhone and get unavalble-devicetoken.
 
+=head1 METHOD
+
+=over 2
+
+=item notify()
+
+Return push client. Need specify parameters.
+
+=back
+
+=head2 PARAMETERS
+
+=over 4
+
+=item Cert
+
+Server certification file. 
+
+=item Key
+
+Server certification key file.
+
+=item passwd
+
+certification password. (option)
+
+=back
+
+=head2 PUSH
+
+Payload contains message, badge and more.
+
+  $APNS->devicetoken($devicetoken);
+  $APNS->write({
+      sandbox => $sandbox,
+      message => $message,
+      badge   => $badge,
+  });
+
+or
+
+  $APNS->devicetoken($devicetoken);
+  $APNS->sandbox($sandbox);
+  $APNS->message($message);
+  $APNS->badge($badge);
+  $APNS->write;
+
 =head1 AUTHOR
 
 haoyayoi E<lt>st.hao.yayoi@gmail.comE<gt>
 
 =head1 SEE ALSO
 
+L<Net::APNS::Notification>
+
 =head1 LICENSE
 
 This library is free software; you can redistribute it and/or modify
